==> kdebase-workspace-4.4.5.tar.bz2: kdebase-workspace-4.4.5/kwin/clients/oxygen/config/oxygenshadowconfigurationui.h <==
#ifndef OxygenShadowConfigurationUI_h
#define OxygenShadowConfigurationUI_h
//////////////////////////////////////////////////////////////////////////////
// OxygenShadowConfigurationUI.h
// -------------------
//
// Copyright (c) 2009 Hugo Pereira Da Costa <hugo.pereira@free.fr>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.
//////////////////////////////////////////////////////////////////////////////

#include <QtGui/QCheckBox>
#include <QtGui/QGroupBox>
#include <ui_oxygenshadowconfigurationui.h>
namespace Oxygen
{

  //_____________________________________________
  class OxygenShadowConfigurationUI: public QGroupBox
  {

    Q_OBJECT

    public:

    //! constructor
    OxygenShadowConfigurationUI( QWidget* );
    Ui_ShadowConfiguraionUI ui;

    signals:

    //! emmitted when configuration is changed
    void changed( void );


  };

}

#endif

==> kdebase-workspace-4.5.0.tar.bz2: kdebase-workspace-4.5.0/kwin/clients/oxygen/config/oxygenshadowconfigurationui.h <==
#ifndef ShadowConfigurationUi_h
#define ShadowConfigurationUi_h
//////////////////////////////////////////////////////////////////////////////
// ShadowConfigurationUi.h
// -------------------
//
// Copyright (c) 2009 Hugo Pereira Da Costa <hugo.pereira@free.fr>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.
//////////////////////////////////////////////////////////////////////////////

#include <QtGui/QCheckBox>
#include <QtGui/QGroupBox>
#include <ui_oxygenshadowconfigurationui.h>
namespace Oxygen
{

  //_____________________________________________
  class ShadowConfigurationUi: public QGroupBox
  {

    Q_OBJECT

    public:

    //! constructor
    ShadowConfigurationUi( QWidget* );
    Ui_ShadowConfiguraionUI ui;

    signals:

    //! emmitted when configuration is changed
    void changed( void );

    protected slots:

    //! update enable state of outer color chooser
    void enableOuterColor( void )
    { ui.outerColor->setEnabled( isChecked() && ui.useOuterColor->isChecked() ); }

  };

}

#endif
